@@ -34,8 +34,7 @@ class Generator(object):
 
             faker_function = getattr(provider, method_name)
 
-            if hasattr(faker_function, '__call__') or \
-                    isinstance(faker_function, (classmethod, staticmethod)):
+            if callable(faker_function):
                 # add all faker method to generator
                 self.set_formatter(method_name, faker_function)
 
@@ -81,11 +80,11 @@ class Generator(object):
         except AttributeError:
             if 'locale' in self.__config:
                 msg = 'Unknown formatter "{0}" with locale "{1}"'.format(
-                    formatter, self.__config['locale']
+                    formatter, self.__config['locale'],
                 )
             else:
                 raise AttributeError('Unknown formatter "{0}"'.format(
-                    formatter
+                    formatter,
                 ))
             raise AttributeError(msg)
 
