@@ -756,3 +756,9 @@ class Provider(AddressProvider):
 
     def state(self):
         return self.random_element(self.states)
+
+    def postcode(self):
+        return self.bothify(self.random_element(self.postcode_formats))
+
+    def city_with_postcode(self):
+        return self.postcode() + " " + self.random_element(self.cities)
