@@ -9,5 +9,5 @@ class Provider(PhoneNumberProvider):
         '+358#########',
         '(+358) #########',
         '0#########',
-        '0## ### ####'
+        '0## ### ####',
     )
