@@ -5,18 +5,11 @@ from __future__ import unicode_literals
 from decimal import Decimal
 import sys
 
+import six
+
 from .. import BaseProvider
 
 
-if sys.version_info[0] == 2:
-    string_types = (basestring,)
-elif sys.version_info[0] == 3:
-    string_types = (str, bytes)
-else:
-    raise SystemError(
-        "Unrecognized python version: {}".format(sys.version_info[0]))
-
-
 class Provider(BaseProvider):
     def pybool(self):
         return self.random_int(0, 1) == 1
@@ -29,14 +22,15 @@ class Provider(BaseProvider):
         :return: String. Random of random length between min and max characters.
         """
         if min_chars is None:
-            return "".join(self.random_letter() for i in range(max_chars))
+            return "".join(self.random_letters(length=max_chars))
         else:
             assert (
                 max_chars >= min_chars), "Maximum length must be greater than or equal to minium length"
             return "".join(
-                self.random_letter() for i in range(
-                    0, self.generator.random.randint(
-                        min_chars, max_chars)))
+                self.random_letters(
+                    length=self.generator.random.randint(min_chars, max_chars),
+                ),
+            )
 
     def pyfloat(self, left_digits=None, right_digits=None, positive=False):
         if left_digits is not None and left_digits < 0:
@@ -59,7 +53,7 @@ class Provider(BaseProvider):
 
         return float("{0}.{1}".format(
             sign * self.random_number(left_digits),
-            self.random_number(right_digits)
+            self.random_number(right_digits),
         ))
 
     def pyint(self):
@@ -112,7 +106,7 @@ class Provider(BaseProvider):
             variable_nb_elements=True,
             *value_types):
 
-        value_types = [t if isinstance(t, string_types) else getattr(t, '__name__', type(t).__name__).lower()
+        value_types = [t if isinstance(t, six.string_types) else getattr(t, '__name__', type(t).__name__).lower()
                        for t in value_types
                        # avoid recursion
                        if t not in ['iterable', 'list', 'tuple', 'dict', 'set']]
@@ -139,12 +133,12 @@ class Provider(BaseProvider):
 
         return dict(zip(
             self.generator.words(nb_elements),
-            self._pyiterable(nb_elements, False, *value_types)
+            self._pyiterable(nb_elements, False, *value_types),
         ))
 
     def pystruct(self, count=10, *value_types):
 
-        value_types = [t if isinstance(t, string_types) else getattr(t, '__name__', type(t).__name__).lower()
+        value_types = [t if isinstance(t, six.string_types) else getattr(t, '__name__', type(t).__name__).lower()
                        for t in value_types
                        # avoid recursion
                        if t != 'struct']
@@ -152,12 +146,12 @@ class Provider(BaseProvider):
             value_types = ['str', 'str', 'str', 'str', 'float',
                            'int', 'int', 'decimal', 'date_time', 'uri', 'email']
 
-        l = []
+        types = []
         d = {}
         nd = {}
         for i in range(count):
             d[self.generator.word()] = self._random_type(value_types)
-            l.append(self._random_type(value_types))
+            types.append(self._random_type(value_types))
             nd[self.generator.word()] = {i: self._random_type(value_types),
                                          i + 1: [self._random_type(value_types),
                                                  self._random_type(value_types),
@@ -166,4 +160,4 @@ class Provider(BaseProvider):
                                                  i + 1: self._random_type(value_types),
                                                  i + 2: [self._random_type(value_types),
                                                          self._random_type(value_types)]}}
-        return l, d, nd
+        return types, d, nd
